import { motion } from 'framer-motion';
import { Mountain, Leaf, FlameKindling, Utensils, Loader2, ImageOff, Trees, Waves, PawPrint } from 'lucide-react';
import { useQuery } from '@tanstack/react-query';
import { GalleryImage } from '@shared/schema';
import { useEffect, useState } from 'react';
import { useIntersectionObserver } from '@/hooks/useIntersectionObserver';

const AboutSection = () => {
  const fadeIn = {
    hidden: { opacity: 0, y: 20 },
    visible: { 
      opacity: 1, 
      y: 0,
      transition: { duration: 0.6 }
    }
  };
  
  // Create state variables to store the images
  const [livingRoomImage, setLivingRoomImage] = useState<string>("");
  const [bedroomImage, setBedroomImage] = useState<string>("");
  const [viewImage, setViewImage] = useState<string>("");
  const [isLoading, setIsLoading] = useState(true);
  
  // Fetch gallery images from API, filtering for about section
  const { data: galleryImages = [], error } = useQuery<GalleryImage[]>({
    queryKey: ['/api/gallery'],
    queryFn: async () => {
      const response = await fetch('/api/gallery');
      if (!response.ok) {
        throw new Error('Failed to fetch gallery images');
      }
      return response.json();
    },
    staleTime: 0,
    refetchOnWindowFocus: true,
  });
  
  // Process fetched images when data is loaded
  useEffect(() => {
    if (galleryImages && galleryImages.length > 0) {
      setIsLoading(false);
      
      // Find images with category "about-section" OR featured images if no about-section images exist
      let aboutSectionImages = galleryImages.filter(img => 
        img.category === "about-section"
      );
      
      // If no about section images were found, use featured images instead
      if (aboutSectionImages.length === 0) {
        aboutSectionImages = galleryImages.filter(img => img.isFeatured);
      }
      
      // If we found appropriate images, use them
      if (aboutSectionImages.length > 0) {
        // Sort them by sortOrder to maintain consistency
        const sortedImages = [...aboutSectionImages].sort((a, b) => 
          ((a.sortOrder || 0) - (b.sortOrder || 0))
        );
        
        // Assign images based on position (first 3)
        if (sortedImages[0]) {
          setLivingRoomImage(sortedImages[0].src);
        }
        
        if (sortedImages[1]) {
          setBedroomImage(sortedImages[1].src);
        }
        
        if (sortedImages[2]) {
          setViewImage(sortedImages[2].src);
        }
      }
    } else if (!error) {
      setIsLoading(false);
    }
  }, [galleryImages, error]);

  return (
    <section id="about" className="py-20 bg-white">
      <div className="container mx-auto px-4 md:px-8">
        <div className="flex flex-col md:flex-row gap-12 items-center">
          <motion.div 
            className="md:w-1/2"
            initial="hidden"
            whileInView="visible"
            viewport={{ once: true, amount: 0.2 }}
            variants={fadeIn}
          >
            <h2 className="font-playfair font-bold text-3xl md:text-4xl text-[hsl(var(--charcoal))] mb-6 relative">
              <span className="inline-block pb-2 relative">
                About Our Chalet
                <span className="absolute bottom-0 left-0 w-1/4 h-1 bg-primary"></span>
              </span>
            </h2>
            <p className="font-inter text-lg text-[hsl(var(--charcoal))]/80 mb-6 leading-relaxed">
              Escape to the breathtaking seclusion of Chalet Kanimbla, a serene haven perched high above the Kanimbla Valley. Set 792 metres above sea level, this four-bedroom luxury chalet offers panoramic 360-degree views, peaceful bushland surrounds, and a chance to truly switch off and unwind.
            </p>
            <p className="font-inter text-lg text-[hsl(var(--charcoal))]/80 mb-8 leading-relaxed">
              From every room, you're treated to sweeping vistas of rolling hills, bushland, and endless skies. Whether you're curled up by the wood-burning fireplace, relaxing in the private sauna, or cooking with loved ones in the fully-equipped kitchen, the chalet is designed to make you feel both at home and a world away.
            </p>
            <div className="flex flex-wrap gap-6 mb-8">
              <div className="flex items-center">
                <Mountain className="text-primary mr-3" />
                <span className="font-inter">Panoramic Views</span>
              </div>
              <div className="flex items-center">
                <Waves className="text-primary mr-3" />
                <span className="font-inter">Sauna</span>
              </div>
              <div className="flex items-center">
                <FlameKindling className="text-primary mr-3" />
                <span className="font-inter">Fireplace</span>
              </div>
              <div className="flex items-center">
                <PawPrint className="text-primary mr-3" />
                <span className="font-inter">Native Wildlife</span>
              </div>
              <div className="flex items-center">
                <Leaf className="text-primary mr-3" />
                <span className="font-inter">Secluded Retreat</span>
              </div>
            </div>
            <button 
              onClick={() => {
                const gallerySection = document.getElementById('gallery');
                if (gallerySection) {
                  gallerySection.scrollIntoView({ behavior: 'smooth' });
                }
              }}
              className="inline-block px-8 py-3 bg-primary hover:bg-[hsl(var(--teal-dark))] text-white font-montserrat font-semibold uppercase tracking-wider rounded-sm transition-colors duration-300"
            >
              View Gallery
            </button>
          </motion.div>
          
          <motion.div 
            className="md:w-1/2 grid grid-cols-2 gap-4"
            initial="hidden"
            whileInView="visible"
            viewport={{ once: true, amount: 0.2 }}
            variants={fadeIn}
          >
            {isLoading ? (
              <div className="col-span-2 flex items-center justify-center h-64">
                <Loader2 className="h-8 w-8 animate-spin text-primary" />
              </div>
            ) : (
              <>
                {/* Living Room Image (Top Left) */}
                <div className="overflow-hidden rounded-lg h-64 bg-[hsl(var(--soft-white))]">
                  {livingRoomImage ? (
                    <img 
                      src={`/api/resolve-image?src=${encodeURIComponent(livingRoomImage)}&t=${Date.now()}`}
                      alt="Chalet living room with fireplace" 
                      className="w-full h-full object-cover transition-transform duration-500 hover:scale-105" 
                      loading="lazy"
                      decoding="async"
                      onError={(e) => {
                        console.error('Error loading image:', livingRoomImage);
                        
                        // Track our attempts to recover
                        const attempts = Number(e.currentTarget.getAttribute('data-recovery-attempts') || '0');
                        e.currentTarget.setAttribute('data-recovery-attempts', (attempts + 1).toString());
                        
                        // Try a few different recovery approaches
                        if (attempts === 0) {
                          // First attempt: If we have an S3 URL, try to resolve it via our API
                          if (livingRoomImage.includes('amazonaws.com')) {
                            // Extract the key part from the URL (path after .amazonaws.com/)
                            const urlParts = livingRoomImage.split('.amazonaws.com/');
                            if (urlParts.length > 1) {
                              const key = urlParts[1].split('?')[0]; // Remove query params
                              const localPath = `/uploads/${key}`; // Adjust to match expected path format
                              const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(localPath)}&t=${Date.now()}`;
                              console.log(`Trying to resolve about section S3 URL: ${resolveUrl}`);
                              e.currentTarget.src = resolveUrl;
                              return;
                            }
                          }
                          
                          // Otherwise, try a direct path for uploads
                          if (livingRoomImage.startsWith('/uploads/')) {
                            // Fix for duplicate uploads in path
                            const fixedPath = livingRoomImage.replace('/uploads/uploads/', '/uploads/');
                            const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(fixedPath)}&t=${Date.now()}`;
                            console.log(`Trying to load about image via resolve-image endpoint: ${resolveUrl}`);
                            e.currentTarget.src = resolveUrl;
                            return;
                          }
                        } 
                        else if (attempts === 1) {
                          // Second attempt: Try direct path
                          if (livingRoomImage.startsWith('/uploads/')) {
                            console.log(`Last attempt: trying direct path: ${livingRoomImage}`);
                            e.currentTarget.src = livingRoomImage;
                            return;
                          }
                        }
                        
                        // If we've tried multiple times and it's still failing, hide the image
                        if (attempts >= 2) {
                          (e.currentTarget as HTMLImageElement).style.display = 'none';
                        }
                      }}
                    />
                  ) : (
                    <div className="flex items-center justify-center h-full">
                      <ImageOff className="h-8 w-8 text-gray-400" />
                    </div>
                  )}
                </div>
                
                {/* Bedroom Image (Top Right) */}
                <div className="overflow-hidden rounded-lg h-64 bg-[hsl(var(--soft-white))]">
                  {bedroomImage ? (
                    <img 
                      src={`/api/resolve-image?src=${encodeURIComponent(bedroomImage)}&t=${Date.now()}`}
                      alt="Chalet bedroom with mountain views" 
                      className="w-full h-full object-cover transition-transform duration-500 hover:scale-105" 
                      loading="lazy"
                      decoding="async"
                      onError={(e) => {
                        console.error('Error loading image:', bedroomImage);
                        
                        // Track our attempts to recover
                        const attempts = Number(e.currentTarget.getAttribute('data-recovery-attempts') || '0');
                        e.currentTarget.setAttribute('data-recovery-attempts', (attempts + 1).toString());
                        
                        // Try a few different recovery approaches
                        if (attempts === 0) {
                          // First attempt: If we have an S3 URL, try to resolve it via our API
                          if (bedroomImage.includes('amazonaws.com')) {
                            // Extract the key part from the URL (path after .amazonaws.com/)
                            const urlParts = bedroomImage.split('.amazonaws.com/');
                            if (urlParts.length > 1) {
                              const key = urlParts[1].split('?')[0]; // Remove query params
                              const localPath = `/uploads/${key}`; // Adjust to match expected path format
                              const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(localPath)}&t=${Date.now()}`;
                              console.log(`Trying to resolve about section S3 URL: ${resolveUrl}`);
                              e.currentTarget.src = resolveUrl;
                              return;
                            }
                          }
                          
                          // Otherwise, try a direct path for uploads
                          if (bedroomImage.startsWith('/uploads/')) {
                            // Fix for duplicate uploads in path
                            const fixedPath = bedroomImage.replace('/uploads/uploads/', '/uploads/');
                            const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(fixedPath)}&t=${Date.now()}`;
                            console.log(`Trying to load about image via resolve-image endpoint: ${resolveUrl}`);
                            e.currentTarget.src = resolveUrl;
                            return;
                          }
                        } 
                        else if (attempts === 1) {
                          // Second attempt: Try direct path
                          if (bedroomImage.startsWith('/uploads/')) {
                            console.log(`Last attempt: trying direct path: ${bedroomImage}`);
                            e.currentTarget.src = bedroomImage;
                            return;
                          }
                        }
                        
                        // If we've tried multiple times and it's still failing, hide the image
                        if (attempts >= 2) {
                          (e.currentTarget as HTMLImageElement).style.display = 'none';
                        }
                      }}
                    />
                  ) : (
                    <div className="flex items-center justify-center h-full">
                      <ImageOff className="h-8 w-8 text-gray-400" />
                    </div>
                  )}
                </div>
                
                {/* View Image (Bottom, Full Width) */}
                <div className="overflow-hidden rounded-lg col-span-2 h-52 bg-[hsl(var(--soft-white))]">
                  {viewImage ? (
                    <img 
                      src={viewImage.startsWith('/uploads/') || viewImage.includes('amazonaws.com')
                        ? `/api/optimize-image?src=${encodeURIComponent(viewImage)}&width=700&quality=78&format=webp`
                        : `${viewImage}?t=${Date.now()}`
                      }
                      srcSet={viewImage.startsWith('/uploads/') || viewImage.includes('amazonaws.com') ? `
                        /api/optimize-image?src=${encodeURIComponent(viewImage)}&width=500&quality=78&format=webp 500w,
                        /api/optimize-image?src=${encodeURIComponent(viewImage)}&width=700&quality=78&format=webp 700w,
                        /api/optimize-image?src=${encodeURIComponent(viewImage)}&width=1000&quality=78&format=webp 1000w
                      ` : undefined}
                      sizes={viewImage.startsWith('/uploads/') || viewImage.includes('amazonaws.com') ? "(max-width: 640px) 500px, (max-width: 1024px) 700px, 700px" : undefined}
                      alt="Panoramic views from Chalet Kanimbla" 
                      className="w-full h-full object-cover transition-transform duration-500 hover:scale-105" 
                      loading="lazy"
                      decoding="async"
                      onError={(e) => {
                        console.error('Error loading image:', viewImage);
                        
                        // Track our attempts to recover
                        const attempts = Number(e.currentTarget.getAttribute('data-recovery-attempts') || '0');
                        e.currentTarget.setAttribute('data-recovery-attempts', (attempts + 1).toString());
                        
                        // Try a few different recovery approaches
                        if (attempts === 0) {
                          // First attempt: If we have an S3 URL, try to resolve it via our API
                          if (viewImage.includes('amazonaws.com')) {
                            // Extract the key part from the URL (path after .amazonaws.com/)
                            const urlParts = viewImage.split('.amazonaws.com/');
                            if (urlParts.length > 1) {
                              const key = urlParts[1].split('?')[0]; // Remove query params
                              const localPath = `/uploads/${key}`; // Adjust to match expected path format
                              const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(localPath)}&t=${Date.now()}`;
                              console.log(`Trying to resolve about section S3 URL: ${resolveUrl}`);
                              e.currentTarget.src = resolveUrl;
                              return;
                            }
                          }
                          
                          // Otherwise, try a direct path for uploads
                          if (viewImage.startsWith('/uploads/')) {
                            // Fix for duplicate uploads in path
                            const fixedPath = viewImage.replace('/uploads/uploads/', '/uploads/');
                            const resolveUrl = `/api/resolve-image?src=${encodeURIComponent(fixedPath)}&t=${Date.now()}`;
                            console.log(`Trying to load about image via resolve-image endpoint: ${resolveUrl}`);
                            e.currentTarget.src = resolveUrl;
                            return;
                          }
                        } 
                        else if (attempts === 1) {
                          // Second attempt: Try direct path
                          if (viewImage.startsWith('/uploads/')) {
                            console.log(`Last attempt: trying direct path: ${viewImage}`);
                            e.currentTarget.src = viewImage;
                            return;
                          }
                        }
                        
                        // If we've tried multiple times and it's still failing, hide the image
                        if (attempts >= 2) {
                          (e.currentTarget as HTMLImageElement).style.display = 'none';
                        }
                      }}
                    />
                  ) : (
                    <div className="flex items-center justify-center h-full">
                      <ImageOff className="h-8 w-8 text-gray-400" />
                    </div>
                  )}
                </div>
              </>
            )}
          </motion.div>
        </div>
      </div>
    </section>
  );
};

export default AboutSection;
